@@ -241,6 +241,12 @@ impl RetroBoard {
         &self.board
     }
 
+    #[inline]
+    #[must_use]
+    pub fn retro_turn(&self) -> Color {
+        self.retro_turn
+    }
+
     #[inline]
     #[must_use]
     pub fn us(&self) -> Bitboard {
